@@ -2,14 +2,15 @@
 #' 
 #' @import httr data.table plyr assertthat
 #' @importFrom stringr str_trim
-#' @param input A data.frame of lat/long data.
+#' @param input A data.frame of lat/long data. There must be columns decimalLatitude and 
+#' decimalLongitude.
 #' @param latitude A vector of latitude's. Must be the same length as the longitude 
 #' vector.
 #' @param longitude A vector of longitude's. Must be the same length as the latitude 
 #' vector.
 #' @param latlong A vector of lat/long pairs. See examples.
-#' @param callopts Options passed on to httr::GET, like curl options for debugging.
-#' @return A new column in the supplied data.frame or a vector with elevation of 
+#' @param callopts Options passed on to \code{httr::GET}, like curl options for debugging.
+#' @return A new column named elevation in the supplied data.frame or a vector with elevation of 
 #' each location in meters. 
 #' @references Uses the Google Elevation API at the following link
 #' \url{https://developers.google.com/maps/documentation/elevation/}
@@ -20,7 +21,7 @@
 #' elevation(dat)
 #' 
 #' # Pass in a vector of lat's and a vector of long's
-#' elevation(latitude=dat$latitude, longitude=dat$longitude)
+#' elevation(latitude=dat$decimalLatitude, longitude=dat$decimalLongitude)
 #' 
 #' # Pass in lat/long pairs in a single vector
 #' pairs <- list(c(31.8496,-110.576060), c(29.15503,-103.59828))
@@ -63,6 +64,9 @@ elevation <- function(input=NULL, latitude=NULL, longitude=NULL, latlong=NULL,
   }
   
   if(is(input, "data.frame")){
+    assert_that(all(c('decimalLatitude','decimalLongitude') %in% names(input)))
+    names(input)[names(input) %in% 'decimalLatitude'] <- "latitude"
+    names(input)[names(input) %in% 'decimalLongitude'] <- "longitude"
     getdata(input)
   } else if(is.null(latlong))
   {
