@@ -2,6 +2,7 @@
 #' 
 #' @template map
 #' @import grid ggplot2 maps
+#' @export
 #' @examples \dontrun{
 #' # Make a map of Puma concolor occurrences
 #' key <- name_backbone(name='Puma concolor', kingdom='plants')$speciesKey
@@ -14,20 +15,20 @@
 #' gbifmap(input=dat)
 #' 
 #' # More than 1 species
-#' library(plyr)
+#' library("plyr")
 #' splist <- c('Cyanocitta stelleri', 'Junco hyemalis', 'Aix sponsa')
 #' keys <- sapply(splist, function(x) name_backbone(name=x, kingdom='plants')$speciesKey,
 #'    USE.NAMES=FALSE)
 #' dat <- occ_search(taxonKey=keys, return='data', limit=50)
 #' gbifmap(ldply(dat))
 #' }
-#' @export
+
 gbifmap <- function(input = NULL, mapdatabase = "world", region = ".", 
                     geom = geom_point, jitter = NULL, customize = NULL)
 {  
-  tomap <- input[complete.cases(input$latitude, input$latitude), ]
-  tomap <- tomap[!tomap$longitude==0 & !tomap$latitude==0,]
-  tomap <- input[-(which(tomap$latitude <=90 || tomap$longitude <=180)), ]
+  tomap <- input[complete.cases(input$decimalLatitude, input$decimalLatitude), ]
+  tomap <- tomap[!tomap$decimalLongitude==0 & !tomap$decimalLatitude==0,]
+  tomap <- input[-(which(tomap$decimalLatitude <=90 || tomap$decimalLongitude <=180)), ]
   tomap$name <- as.factor(gbif_capwords(tomap$name, onlyfirst=TRUE))
   
   if(length(unique(tomap$name))==1){ theme2 <- theme(legend.position="none") } else 
@@ -38,7 +39,7 @@ gbifmap <- function(input = NULL, mapdatabase = "world", region = ".",
   
   ggplot(world, aes(long, lat)) +
     geom_polygon(aes(group=group), fill="white", color="gray40", size=0.2) +
-    geom(data=tomap, aes(longitude, latitude, colour=name), 
+    geom(data=tomap, aes(decimalLongitude, decimalLatitude, colour=name), 
          alpha=0.4, size=3, position=jitter) +
     scale_color_brewer("", type="qual", palette=6) +
     labs(x="", y="") +
