@@ -3,7 +3,7 @@
 #' @template all
 #' @import httr
 #' @import plyr
-#' @importFrom RJSONIO toJSON
+#' @importFrom RJSONIO toJSON fromJSON
 #' @param scientificname A character vector of scientific names.
 #' @return A \code{data.frame} containing fields extracted from parsed 
 #' taxon names. Fields returned are the union of fields extracted from
@@ -23,6 +23,8 @@ parsenames <- function(scientificname) {
                                     'application/json')),
              body=RJSONIO::toJSON(scientificname))
   stop_for_status(tt)
-  res <- content(tt)
+  assert_that(tt$headers$`content-type`=='application/json')
+  temp <- content(tt, as = 'text', encoding = "UTF-8")
+  res <- RJSONIO::fromJSON(temp, simplifyWithNames = FALSE)
   do.call(rbind.fill, lapply(res, as.data.frame))
 }
\ No newline at end of file
