@@ -3,7 +3,7 @@ context("dataset_suggest")
 tt <- dataset_suggest(query="Amazon", type="OCCURRENCE")
 test_that("type query returns the correct class", {
   expect_is(tt, "data.frame")
-  expect_is(tt[1,1], "factor")
+  expect_is(tt[1,1], "character")
 })
 
 
@@ -12,15 +12,15 @@ test_that("type query returns the correct class", {
 tt <- dataset_suggest(query="amsterdam")
 test_that("search query returns the correct class", {
   expect_is(tt, "data.frame")
-  expect_is(tt$hostingOrganization, "factor")
-  expect_is(tt$hostingOrganization[[1]], "factor")
+  expect_is(tt$hostingOrganization, "character")
+  expect_is(tt$hostingOrganization[[1]], "character")
 })
 
 # Limited search
 tt <- dataset_suggest(type="OCCURRENCE", limit=2)
 test_that("limited search returns the correct class", {
   expect_is(tt, "data.frame")
-  expect_is(tt[1,1], "factor")
+  expect_is(tt[1,1], "character")
 })
 test_that("limited search returns the correct dims", {
   expect_equal(dim(tt), c(2,8))
