@@ -7,7 +7,7 @@ test_that("returns the correct class", {
   expect_is(tt, "list")
   expect_is(tt$meta, "data.frame")
   expect_is(tt$meta$endOfRecords, "logical")
-  expect_is(tt$data$canonicalName, "factor")
+  expect_is(tt$data$canonicalName, "character")
   expect_is(tt$data$classKey, "numeric")
   
   expect_is(uu, "data.frame")
