@@ -2,8 +2,8 @@ context("stylegeojson")
 
 library(plyr)
 splist <- c('Accipiter erythronemius', 'Junco hyemalis', 'Aix sponsa')
-keys <- sapply(splist, function(x) name_backbone(name=x, kingdom='plants')$speciesKey, USE.NAMES=FALSE)
-dat <- occ_search(keys, georeferenced = TRUE, limit = 50)
+keys <- sapply(splist, function(x) name_suggest(x)$key[1], USE.NAMES=FALSE)
+dat <- occ_search(keys, hasCoordinate = TRUE, limit = 50)
 dat <- ldply(dat, "[[", "data")
 dat2 <- stylegeojson(input=dat, var=".id", color=c("#976AAE","#6B944D","#BD5945"), size=c("small","medium","large"))
 
@@ -17,5 +17,5 @@ test_that("returns the correct value", {
 })
 
 test_that("returns the correct dimensions", {
-  expect_equal(dim(dat2), c(114,7))
+  expect_equal(dim(dat2), c(115,7))
 })
\ No newline at end of file
